==> myfaces-extval-module-1.1.4-source-release.zip: myfaces-extval-module-1.1.4/core/src/main/java/org/apache/myfaces/extensions/validator/core/validation/EmptyValueAwareValidationStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.extensions.validator.core.validation;

import org.apache.myfaces.extensions.validator.internal.UsageInformation;
import org.apache.myfaces.extensions.validator.internal.UsageCategory;

import static java.lang.annotation.ElementType.TYPE;
import java.lang.annotation.Target;
import java.lang.annotation.Retention;
import java.lang.annotation.Documented;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Marker annotation to indicate that the strategy can handle empty values (strings of length 0) as values to validate.
 * This was introduced to have the correct behaviour in relation to the parameter javax.faces.VALIDATE_EMPTY_FIELDS.
 * 
 * @author Gerhard Petracek
 * @since x.x.3
 */
@Target(TYPE)
@Retention(RUNTIME)
@Documented
@UsageInformation(UsageCategory.API)
public @interface EmptyValueAwareValidationStrategy
{
}

==> myfaces-extval-module-1.2.6-source-release.zip: myfaces-extval-module-1.2.6/core/src/main/java/org/apache/myfaces/extensions/validator/core/validation/EmptyValueAwareValidationStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.extensions.validator.core.validation;

import org.apache.myfaces.extensions.validator.internal.UsageInformation;
import org.apache.myfaces.extensions.validator.internal.UsageCategory;

import static java.lang.annotation.ElementType.TYPE;
import java.lang.annotation.Target;
import java.lang.annotation.Retention;
import java.lang.annotation.Documented;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Marker annotation to indicate that the strategy can handle empty values (strings of length 0) as values to validate.
 * If a {@link org.apache.myfaces.extensions.validator.core.validation.strategy.ValidationStrategy} is NOT annotated
 * with this marker, it doesn't have to care about empty values.
 * 
 * @author Gerhard Petracek
 * @since x.x.3
 */
@Target(TYPE)
@Retention(RUNTIME)
@Documented
@UsageInformation(UsageCategory.API)
public @interface EmptyValueAwareValidationStrategy
{
}
